﻿using IdentityModel;
using StackExchange.Profiling.Internal;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using UAParser;

namespace IMES_Middleware_Platform.Api.Core.Handlers
{
    public class HttpHelper
    {

        private readonly HttpClient _httpClient;

        public HttpHelper()
        {
            _httpClient = new HttpClient();
            // 配置超时（HttpClient 默认 100s，此处设为 10 分钟）
            _httpClient.Timeout = TimeSpan.FromMinutes(10);
        }

        public async Task<string> GetAsync(string url, string nonce, string timestamp, string signature)
        {
            try
            {


                // 设置 UserAgent
               // _httpClient.DefaultRequestHeaders.UserAgent.ParseAdd("Apifox/1.0.0 (https://apifox.com)");

                // 请求 URL（含查询参数）
                var requestUrl = "https://cma-fds.org.cn/api/open/v1/station/list?page=0&size=20";

                // 创建请求对象
                var request = new HttpRequestMessage(HttpMethod.Get, url);

                // 添加自定义请求头
                request.Headers.Add("sign_method", "HMAC-SM3");
                request.Headers.Add("secret_id", "AwTHQMpzVvsCe7qx");
                request.Headers.Add("nonce", nonce);
                request.Headers.Add("timestamp", timestamp);
                request.Headers.Add("signature", signature);

                try
                {
                    // 发送请求
                    var response = await _httpClient.SendAsync(request);

                    // 确保响应成功
                    response.EnsureSuccessStatusCode();

                    // 读取响应内容
                    var content = await response.Content.ReadAsStringAsync();
                    return content;
                }
                catch (HttpRequestException ex)
                {
                    Console.WriteLine($"HTTP 请求失败: {ex.Message}");
                }
                catch (TaskCanceledException ex)
                {
                    Console.WriteLine($"请求超时: {ex.Message}");
                }
                return null;
            }
            catch (HttpRequestException e)
            {
                return null;
            }
        }
        static async Task<string> GetAsync(string url, System.Collections.Generic.Dictionary<string, string> headers)
        {
            try 
            {
                using (HttpClient client = new HttpClient())
                {
                    // 添加请求头
                    foreach (var header in headers)
                    {
                        client.DefaultRequestHeaders.Add(header.Key, header.Value);
                    }

                    // 发送 GET 请求
                    HttpResponseMessage response = await client.GetAsync(url);

                    // 确保请求成功
                    response.EnsureSuccessStatusCode();

                    // 读取响应内容
                    string responseData = await response.Content.ReadAsStringAsync();
                    return responseData;
                }
            }
            catch(HttpRequestException e)
            {
                return null;
            }
          
        }
        public async Task<string> GetDispensersDataAsync(string baseUrl, string accessToken, string cookie, string expand1, string expand2, string search = "", int size = 20, int page = 0)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                httpClient.BaseAddress = new Uri(baseUrl);
                httpClient.DefaultRequestHeaders.Add("Authorization", $"Bearer {accessToken}");
                // _httpClient.DefaultRequestHeaders.Add("Cookie", cookie);

                string endpoint = $"?expand=station.company&expand={expand1}&expand={expand2}&size={size}&page={page}&search={search}";

                HttpResponseMessage response = await httpClient.GetAsync(endpoint);
                response.EnsureSuccessStatusCode();
                if (response.IsSuccessStatusCode)
                {
                    return await response.Content.ReadAsStringAsync();
                }
                else
                {
                    Console.WriteLine($"Error: {response.StatusCode} - {response.ReasonPhrase}");
                    return null;
                }
            }

        }
        public async Task<string> GetLifecycleAsync(string baseUrl, string accessToken, int id, int size = 20, int page = 0)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                httpClient.BaseAddress = new Uri(baseUrl);
                httpClient.DefaultRequestHeaders.Add("Authorization", $"Bearer {accessToken}");
                // _httpClient.DefaultRequestHeaders.Add("Cookie", cookie);

                string endpoint = $"?expand=createdBy.name&expand=createdBy.id&page={page}&size={size}&sort=id,desc&search=modelId:{id},type:Dispenser,content.deviceStatus<>null";

                HttpResponseMessage response = await httpClient.GetAsync(endpoint);
                response.EnsureSuccessStatusCode();
                if (response.IsSuccessStatusCode)
                {
                    return await response.Content.ReadAsStringAsync();
                }
                else
                {
                    Console.WriteLine($"Error: {response.StatusCode} - {response.ReasonPhrase}");
                    return null;
                }
            }

        }
        public async Task<string> GetAlarmHistoryAsync(string baseUrl, string accessToken, int id, int size = 20, int page = 0)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                httpClient.BaseAddress = new Uri(baseUrl);
                httpClient.DefaultRequestHeaders.Add("Authorization", $"Bearer {accessToken}");
                // _httpClient.DefaultRequestHeaders.Add("Cookie", cookie);
                //https://cma-fds.org.cn/api/v1/notices?expand=station&expand=dispenser&expand=alarm&page=0&size=5&sort=id,desc&search=dispenser.id:34
                string endpoint = $"?expand=station&expand=dispenser&expand=alarm&page={page}&size={size}&sort=id,desc&search=dispenser.id:{id}";

                HttpResponseMessage response = await httpClient.GetAsync(endpoint);
                response.EnsureSuccessStatusCode();
                if (response.IsSuccessStatusCode)
                {
                    return await response.Content.ReadAsStringAsync();
                }
                else
                {
                    Console.WriteLine($"Error: {response.StatusCode} - {response.ReasonPhrase}");
                    return null;
                }
            }
        }

        public async Task<string> GetDispensersDetailsAsync(string baseUrl, string accessToken, int id, int size = 20, int page = 0)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                httpClient.BaseAddress = new Uri(baseUrl);
                httpClient.DefaultRequestHeaders.Add("Authorization", $"Bearer {accessToken}");
                // _httpClient.DefaultRequestHeaders.Add("Cookie", cookie);
                //https://cma-fds.org.cn/api/v1/notices?expand=station&expand=dispenser&expand=alarm&page=0&size=5&sort=id,desc&search=dispenser.id:34
                string endpoint = $"?expand=station&expand=supplier&expand=blackBoxesOnlineTime&expand=nozzleControls&expand=nozzleControls.code&expand=nozzleControls.fuel&expand=nozzleControls.taxControl&expand=nozzleControls.taxControl.supplier&expand=nozzleControls.taxControl.calculatorMainboard.supplier&expand=nozzleControls.taxControl.calculatorMainboard.calculatorSoftware.supplier&expand=nozzleControls.encoderControls.supplier&expand=nozzleControls.encoderControls.meter.supplier&expand=nozzleControls.displayControls.supplier&expand=nozzleControls.blackBox.supplier&expand=nozzleControls.encoderControls.encoderSoftware.supplier&expand=nozzleControls.taxControl.taxSoftware.supplier&expand=nozzleControls.valveControls.supplier&expand=nozzleControls.valveControls.valveSoftware.supplier&expand=nozzleControls.vaporRecoveryControl&expand=nozzleControls.vaporRecoveryControl.vaporRecoverySoftware.supplier&expand=nozzleControls.vaporRecoveryControl.supplier";

                HttpResponseMessage response = await httpClient.GetAsync(endpoint);
                response.EnsureSuccessStatusCode();
                if (response.IsSuccessStatusCode)
                {
                    return await response.Content.ReadAsStringAsync();
                }
                else
                {
                    Console.WriteLine($"Error: {response.StatusCode} - {response.ReasonPhrase}");
                    return null;
                }
            }
        }

        public async Task<string> PostAsync(string url, HttpContent content)
        {
            try
            {
                HttpResponseMessage response = await _httpClient.PostAsync(url, content);
                response.EnsureSuccessStatusCode();
                string responseBody = await response.Content.ReadAsStringAsync();
                return responseBody;
            }
            catch (HttpRequestException e)
            {
                return null;
            }
        }

        public async Task<string> GetTaxcontrolsAsync(string baseUrl, string accessToken, int size = 20, int page = 0)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                httpClient.BaseAddress = new Uri(baseUrl);
                httpClient.DefaultRequestHeaders.Add("Authorization", $"Bearer {accessToken}");
                // _httpClient.DefaultRequestHeaders.Add("Cookie", cookie);
                //https://cma-fds.org.cn/api/v1/notices?expand=station&expand=dispenser&expand=alarm&page=0&size=5&sort=id,desc&search=dispenser.id:34
                string endpoint = $"?expand=station.company&expand=blackBox.dispenser.supplier&expand=station&expand=blackBox.dispenser&expand=supplier&page={page}&size={size}&search=";

                HttpResponseMessage response = await httpClient.GetAsync(endpoint);
                response.EnsureSuccessStatusCode();
                if (response.IsSuccessStatusCode)
                {
                    return await response.Content.ReadAsStringAsync();
                }
                else
                {
                    Console.WriteLine($"Error: {response.StatusCode} - {response.ReasonPhrase}");
                    return null;
                }
            }
        }
    }
}
