﻿using FreeSql.DataAnnotations;
using IMES_Middleware_Platform.Api.Domain.FuelDispenser.Dto;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ZhonTai.Admin.Core.Entities;

namespace IMES_Middleware_Platform.Api.Domain.FuelDispenser
{
    /// <summary>
    /// 显示屏
    /// </summary>
    [Table(Name = "DisplayControl")]
    public class DisplayControlEntity : EntityAdd
    {
        /// <summary>
        /// 显示屏唯一标识符
        /// <remarks>长度限制：0-32字符</remarks>
        /// </summary>
        public string Uuid { get; set; }

        /// <summary>
        /// 设备原厂序列号
        /// <remarks>长度限制：0-32字符</remarks>
        /// </summary>
        public string Sn { get; set; }

        /// <summary>
        /// 关联油机供应商ID
        /// </summary>
        public long DispenserSupplierId { get; set; }

        /// <summary>
        /// 标识是否存在未上报的疑似脏数据
        /// <remarks>true表示存在未上报的脏数据</remarks>
        /// </summary>
        public bool Dirty { get; set; }

        /// <summary>
        /// 安全装置ID
        /// <seealso cref="BlackBox"/>
        /// </summary>
        public int? BlackBoxID { get; set; }

        /// <summary>
        /// 站点ID
        /// <seealso cref="Station"/>
        /// </summary>
        public int?  StationID { get; set; }

        /// <summary>
        /// 供应商ID
        /// <seealso cref="Supplier"/>
        /// </summary>
        public int? SupplierID { get; set; }



        /// <summary>
        /// 设备在线状态
        /// <seealso cref="OnlineStatus"/>
        /// </summary>
        public string OnlineStatus { get; set; }

        /// <summary>
        /// 设备注册/绑定状态
        /// <seealso cref="DeviceStatus"/>
        /// </summary>
        public string DeviceStatus { get; set; }

        /// <summary>
        /// 设备告警等级
        /// <remarks>1-一般告警，2-严重告警</remarks>
        /// </summary>
        public int DeviceAlarmLevel { get; set; }

        /// <summary>
        /// 设备生产日期
        /// </summary>
        public DateTime? ProductTime { get; set; }

        /// <summary>
        /// 设备出厂日期
        /// <remarks>可为空值</remarks>
        /// </summary>
        public DateTime? SoldTime { get; set; }

        /// <summary>
        /// 设备启用日期
        /// <remarks>可为空值</remarks>
        /// </summary>
        public DateTime? StartTime { get; set; }

        /// <summary>
        /// 设备安装日期
        /// <remarks>可为空值</remarks>
        /// </summary>
        public DateTime? FixTime { get; set; }

        /// <summary>
        /// 设备照片存储ID
        /// <remarks>可为空值</remarks>
        /// </summary>
        public long? PhotoId { get; set; }

        /// <summary>
        /// 设备错误代码集合
        /// <remarks>初始化默认空集合</remarks>
        /// </summary>
        public string Alarms { get; set; } 

        /// <summary>
        /// 法制软件版本号
        /// </summary>
        public string LawSwv { get; set; }

        /// <summary>
        /// 法制软件标识
        /// </summary>
        public string LawSwi { get; set; }
    }
}
